@@ -21,7 +21,7 @@ Palapeli::SlicerSelector::SlicerSelector(QWidget* parent)
 	setSelectionMode(QAbstractItemView::SingleSelection);
 	connect(this, &SlicerSelector::itemSelectionChanged, this, &SlicerSelector::slotSelectionChanged);
     //load slicer plugins
-    const QVector<KPluginMetaData> offers = KPluginMetaData::findPlugins(QStringLiteral("palapelislicers"));
+    const QList<KPluginMetaData> offers = KPluginMetaData::findPlugins(QStringLiteral("palapelislicers"));
 
 	for (const KPluginMetaData &offer : offers)
     {
@@ -87,7 +87,7 @@ Palapeli::SlicerSelection Palapeli::SlicerSelector::currentSelection() const
 	if (item)
 	{
 		const QVariant selIndex = item->data(0, Qt::UserRole);
-		if (selIndex.type() == QVariant::Int)
+		if (selIndex.metaType().id() == QMetaType::Int)
 			return m_knownSelections.value(selIndex.toInt());
 	}
 	//empty or invalid selection
