@@ -21,10 +21,6 @@
 
 int main(int argc, char** argv)
 {
-    // Fixes blurry icons with fractional scaling
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    QGuiApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
-#endif
     QApplication app(argc, argv);
 
     KLocalizedString::setApplicationDomain("palapeli");
@@ -41,18 +37,21 @@ int main(int argc, char** argv)
     about.addCredit (i18n ("Johannes Loehnert"),
             i18n ("The option to preview the completed puzzle"),
             QStringLiteral("loehnert.kde@gmx.de"));
-    QCommandLineParser parser;
+
     KAboutData::setApplicationData(about);
+    QApplication::setWindowIcon(QIcon::fromTheme(QStringLiteral("palapeli")));
+
     KCrash::initialize();
+
+    QCommandLineParser parser;
     parser.addPositionalArgument(QStringLiteral("puzzlefile"), i18n("Path to puzzle file (will be opened if -i is not given)"));
     const QCommandLineOption importOption(QStringList() << QStringLiteral("i") << QStringLiteral("import"), i18n("Import the given puzzle file into the local collection (does nothing if no puzzle file is given). The main window will not be shown after importing the given puzzle."));
     parser.addOption(importOption);
-
     about.setupCommandLine(&parser);
+
     parser.process(app);
     about.processCommandLine(&parser);
 
-
     //NOTE: Syntax errors are reported on stderr, while file errors are presented to the user.
     if (parser.isSet(importOption)) {
         //perform import request
@@ -72,6 +71,6 @@ int main(int argc, char** argv)
         //no import request, show main window
         (new Palapeli::MainWindow(path))->show();
     }
-    app.setWindowIcon(QIcon::fromTheme(QStringLiteral("palapeli")));
+
     return app.exec();
 }
